#! /bin/sh
#

#
# Include config variables
#
. ./config


#
# Try to find wish 8.3
#
test -x "$WISH" || WISH=$( (type -p wish8.3 || type -p wish) 2>/dev/null)
test -x "$WISH" || {

	echo "No wish8.3 or wish shell found."
	echo "Please install Tcl/Tk or edit the file 'config' by hand."
	exit 1
	}

#
# Try to find tclsh 8.3
#
test -x "$TCLSH" || TCLSH=$( (type -p tclsh8.3 || type -p tclsh) 2>/dev/null)
test -x "$TCLSH" || {

	echo "No tclsh8.3 or tclsh shell found."
        echo "Please install Tcl/Tk or edit the file 'config' by hand."
        exit 1
        }

#
# Build the tkpasman executable
#
sed -e "s,@wish@,$WISH,"		\
    -e "s,@tclsh@,$TCLSH,"		\
    -e "s,@configfile@,$CONFIGFILE,"	\
    -e "s,@pwdfile@,$PWDFILE,"	\
    -e "s,@version@,$VERSION,"	\
    tkpasman-hdr.tcl > $PROGNAME

#
# If requested, find and initialize OpenSSL
#
if test "$USE_OPENSSL" == "true" ; then

  # find openssl
  found=0
  if test -x "$OPENSSL" ; then
    found=1
  else
    IFS=':'
    for prog in openssl ssl
    do
      for path in $PATH    \
        /usr/ssl/bin       \
        /usr/openssl/bin   \
        /usr/local/ssl/bin \
        /usr/local/openssl/bin
      do
        if test -x "$path/$prog" ; then
          found=1
          OPENSSL="$path/$prog"
          break 2
        fi
      done
    done
  fi
  if test $found -gt 0 ; then
    echo "Found OpenSSL program: $OPENSSL"
    #OpenSSL was found.
    if ENC=`$OPENSSL list-cipher-commands|sort|grep -E "^($ENC)\$"|head -1` ; then
      if echo bla|$OPENSSL $ENC -e -pass stdin|
          $OPENSSL $ENC -d -k bla; then
        # It Works!
        echo "set ssl(cmd) {$OPENSSL}"	>> $PROGNAME
        echo "set ssl(enc) {$ENC}"	>> $PROGNAME
        echo "set ssl(passwd) {}"	>> $PROGNAME
        echo "Enabling OpenSSL support:"
        echo "  openssl: $OPENSSL"
        echo "  enc:     $ENC"
        if echo bla|$OPENSSL $ENC -salt -pass stdin|
            $OPENSSL $ENC -d -salt -k bla; then
          # Salt option works!
          echo "set ssl(salt) -salt"    >> $PROGNAME
          echo "  salt:    yes"
        else
          echo "set ssl(salt) {}"	>> $PROGNAME
          echo "  salt:    no"
        fi
        cat WARNING
      else
        echo "OpenSSL test failed, not enabling OpenSSL support"
      fi
    fi
  else
    echo "Not found OpenSSL program"
  fi
fi

#
# Build in Help file
#
echo -n "set Help {"	>> $PROGNAME
cat README		>> $PROGNAME
echo "}"		>> $PROGNAME

#
# Assemble the rest of the program, leaving out comments and empty lines
#
sed -e '/^[[:space:]]*#.*$/d' \
    -e '/^[[:space:]]*$/d'    \
    -e 's/^[[:space:]][[:space:]]*//' \
    -e 's/[[:space:]][[:space:]]*/ /g' \
    cooltk.tcl tkpasman.tcl	>> $PROGNAME
chmod 0755 $PROGNAME
echo "Built $PROGNAME succesfully."
